package com.leromro.core.service;

import java.util.List;
import com.baomidou.mybatisplus.extension.service.IService;
import com.leromro.core.domain.VolunteerAccountChange;

/**
 * 志愿者账号变动明细Service接口
 * 
 * @author ruoyi
 * @date 2025-04-11
 */
public interface IVolunteerAccountChangeService extends IService<VolunteerAccountChange>
{
    /**
     * 查询志愿者账号变动明细
     * 
     * @param volunteerAccountChangeId 志愿者账号变动明细主键
     * @return 志愿者账号变动明细
     */
    public VolunteerAccountChange selectVolunteerAccountChangeByVolunteerAccountChangeId(Long volunteerAccountChangeId);

    /**
     * 查询志愿者账号变动明细列表
     * 
     * @param volunteerAccountChange 志愿者账号变动明细
     * @return 志愿者账号变动明细集合
     */
    public List<VolunteerAccountChange> selectVolunteerAccountChangeList(VolunteerAccountChange volunteerAccountChange);

    /**
     * 新增志愿者账号变动明细
     * 
     * @param volunteerAccountChange 志愿者账号变动明细
     * @return 结果
     */
    public Boolean insertVolunteerAccountChange(VolunteerAccountChange volunteerAccountChange);

    /**
     * 修改志愿者账号变动明细
     * 
     * @param volunteerAccountChange 志愿者账号变动明细
     * @return 结果
     */
    public Boolean updateVolunteerAccountChange(VolunteerAccountChange volunteerAccountChange);

    /**
     * 批量删除志愿者账号变动明细
     * 
     * @param volunteerAccountChangeIds 需要删除的志愿者账号变动明细主键集合
     * @return 结果
     */
    public int deleteVolunteerAccountChangeByVolunteerAccountChangeIds(Long[] volunteerAccountChangeIds);

    /**
     * 删除志愿者账号变动明细信息
     * 
     * @param volunteerAccountChangeId 志愿者账号变动明细主键
     * @return 结果
     */
    public int deleteVolunteerAccountChangeByVolunteerAccountChangeId(Long volunteerAccountChangeId);
}
